@@ -14,11 +14,12 @@ class Command(BaseCommand):
 
         router = SockJSRouter(
             SockJSConnection,
-            self.config.listen_location)
+            self.config.listen_location,
+            user_settings=self.config.router_settings)
         app = tornado.web.Application(router.urls)
 
         app.listen(self.config.listen_port, address=self.config.listen_addr)
         try:
             io_loop.start()
         except KeyboardInterrupt:
-            pass
\ No newline at end of file
+            pass
